==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/user/MapUserConsentEntityDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserConsentEntityDelegate implements org.keycloak.models.map.user.MapUserConsentEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserConsentEntity> delegateProvider;
    public MapUserConsentEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserConsentEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getClientId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID).getClientId();
    }
    @Override public void setClientId(String clientId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID, clientId).setClientId(clientId);
    }
    @Override public java.util.Set<String> getGrantedClientScopesIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS).getGrantedClientScopesIds();
    }
    @Override public void addGrantedClientScopesId(String scope) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, scope).addGrantedClientScopesId(scope);
    }
    @Override public void setGrantedClientScopesIds(java.util.Set<String> scopesIds) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, scopesIds).setGrantedClientScopesIds(scopesIds);
    }
    @Override public void removeGrantedClientScopesId(String scopesId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, scopesId).removeGrantedClientScopesId(scopesId);
    }
    @Override public Long getCreatedDate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE).getCreatedDate();
    }
    @Override public void setCreatedDate(Long createdDate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE, createdDate).setCreatedDate(createdDate);
    }
    @Override public Long getLastUpdatedDate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE).getLastUpdatedDate();
    }
    @Override public void setLastUpdatedDate(Long lastUpdatedDate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE, lastUpdatedDate).setLastUpdatedDate(lastUpdatedDate);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/user/MapUserConsentEntityDelegate.java <==
package org.keycloak.models.map.user;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserConsentEntityDelegate implements org.keycloak.models.map.user.MapUserConsentEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.user.MapUserConsentEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserConsentEntity> delegateProvider;
    public MapUserConsentEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserConsentEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserConsentEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getClientId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID).getClientId();
    }
    @Override public void setClientId(String clientId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID, clientId).setClientId(clientId);
    }
    @Override public java.util.Set<String> getGrantedClientScopesIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS).getGrantedClientScopesIds();
    }
    @Override public void addGrantedClientScopesId(String scope) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, scope).addGrantedClientScopesId(scope);
    }
    @Override public void setGrantedClientScopesIds(java.util.Set<String> scopesIds) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, scopesIds).setGrantedClientScopesIds(scopesIds);
    }
    @Override public void removeGrantedClientScopesId(String scopesId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, scopesId).removeGrantedClientScopesId(scopesId);
    }
    @Override public Long getCreatedDate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE).getCreatedDate();
    }
    @Override public void setCreatedDate(Long createdDate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE, createdDate).setCreatedDate(createdDate);
    }
    @Override public Long getLastUpdatedDate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE).getLastUpdatedDate();
    }
    @Override public void setLastUpdatedDate(Long lastUpdatedDate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE, lastUpdatedDate).setLastUpdatedDate(lastUpdatedDate);
    }
}
